public inbox for pve-devel@lists.proxmox.com
 help / color / mirror / Atom feed
From: "Max R. Carrara" <m.carrara@proxmox.com>
To: pve-devel@lists.proxmox.com
Subject: [PATCH pve-storage v1 25/54] tree-wide: replace usages of BACKUP_EXT_RE_2 with parsing functions
Date: Wed, 22 Apr 2026 13:12:51 +0200	[thread overview]
Message-ID: <20260422111322.257380-26-m.carrara@proxmox.com> (raw)
In-Reply-To: <20260422111322.257380-1-m.carrara@proxmox.com>

Add support for the 'backup' volume type in
`PVE::Storage::Common::Parse`.

Also add corresponding test cases.

Use the module's parsing functions to replace usages of the
`PVE::Storage::BACKUP_EXT_RE_2` regex across the repository.

Note that the new regex for parsing 'backup' vtype file paths is also
able to optionally extract the VMID and the type of guest from the
file name. This makes it possible to further simplify some parts of
the original logic.

As done with the `ISO_EXT_RE_0` and `VZTMPL_EXT_RE_1` regexes, keep
the `BACKUP_EXT_RE_2` regex around for now, since it's public and
therefore also part of the storage API. On an APIVER + APIAGE bump,
this regex should be marked for removal as well, like the others.

Additionally, the `COMPRESSOR_RE` constant in `PVE::Storage::Plugin`
is now unused. Together with its related `KNOWN_COMPRESSION_FORMATS`
constant, it should be phased out and replaced eventually. Add a TODO
comment for that.

In the meantime, keep track of the compression formats for specific
vtypes in the `::Common::Parse` module until we move them to a more
adequate place.

Signed-off-by: Max R. Carrara <m.carrara@proxmox.com>
---
 src/PVE/Storage.pm                          |   4 +-
 src/PVE/Storage/Common/Parse.pm             |  39 +++++
 src/PVE/Storage/Common/test/parser_tests.pl | 181 ++++++++++++++++++++
 src/PVE/Storage/Plugin.pm                   |  37 ++--
 4 files changed, 240 insertions(+), 21 deletions(-)

diff --git a/src/PVE/Storage.pm b/src/PVE/Storage.pm
index d5b0b637..ce6d2154 100755
--- a/src/PVE/Storage.pm
+++ b/src/PVE/Storage.pm
@@ -765,9 +765,7 @@ sub path_to_volume_id {
         }

         if ($vtype eq 'backup') {
-            return if $filename !~ m!/([^/]+$BACKUP_EXT_RE_2)$!;
-            my $name = $1;
-            return "$sid:backup/$name";
+            return parse_path_as_volid($sid, $scfg, $path, $vtype);
         }

         if ($vtype eq 'snippets') {
diff --git a/src/PVE/Storage/Common/Parse.pm b/src/PVE/Storage/Common/Parse.pm
index b18ef576..950f6b18 100644
--- a/src/PVE/Storage/Common/Parse.pm
+++ b/src/PVE/Storage/Common/Parse.pm
@@ -35,12 +35,16 @@ primarily related to.

 my @VZTMPL_COMPRESSION_EXTENSIONS = ('gz', 'xz', 'zst', 'bz2');

+my @BACKUP_COMPRESSION_EXTENSIONS = ('gz', 'lzo', 'zst', 'bz2');
+
 my sub join_to_re_alternations(@list) {
     return join('|', map { quotemeta } @list);
 }

 my $RE_VZTMPL_COMPRESSION_EXTENSIONS = join_to_re_alternations(@VZTMPL_COMPRESSION_EXTENSIONS);

+my $RE_BACKUP_COMPRESSION_EXTENSIONS = join_to_re_alternations(@BACKUP_COMPRESSION_EXTENSIONS);
+
 my $RE_PARENT_DIR = quotemeta('..');
 my $RE_CONTAINS_PARENT_DIR = qr!
     ( ^$RE_PARENT_DIR/ )  #  ../ --> Beginning of path
@@ -50,6 +54,11 @@ my $RE_CONTAINS_PARENT_DIR = qr!
     ( /$RE_PARENT_DIR$ )  # /..  --> End of path
 !xn;

+# A vmid is an integer between 100 and 999_999_999
+# See: https://git.proxmox.com/?p=pve-common.git;a=blob;f=src/PVE/JSONSchema.pm;h=17e7126a6c42f8326a1da890680af10b6106d906;hb=refs/heads/master#l62
+# See also: https://git.proxmox.com/?p=pve-common.git;a=blob;f=src/PVE/JSONSchema.pm;h=17e7126a6c42f8326a1da890680af10b6106d906;hb=refs/heads/master#l304
+my $RE_VMID = qr![1-9][0-9]{2,8}!;
+
 my $RE_ISO_FILE_PATH = qr!
     (?<path>
         (?<file> [^/]+ \. (?<ext> (?i: iso|img) ) )
@@ -69,14 +78,44 @@ my $RE_VZTMPL_FILE_PATH = qr!
     )
 !xn;

+my $RE_GUEST_VZDUMP_BACKUP_FILE_NAME = qr!
+    vzdump
+    - (?<type> openvz|lxc|qemu)
+    - (?<vmid> $RE_VMID)
+    - [^/]+
+!xn;
+
+my $RE_BACKUP_FILE_PATH = qr!
+    (?<path>
+        (?<file>
+            (
+                ($RE_GUEST_VZDUMP_BACKUP_FILE_NAME)
+                |
+                ([^/]+)
+            )
+            \.
+            (?<ext>
+                (?<ext_archive> tgz)
+                |
+                (
+                    (?<ext_archive> tar|vma)
+                    ( \. (?<ext_compression> $RE_BACKUP_COMPRESSION_EXTENSIONS) )?
+                )
+            )
+        )
+    )
+!xn;
+
 my $RE_FILE_PATH_FOR_VTYPE = {
     iso => qr/^$RE_ISO_FILE_PATH$/,
     vztmpl => qr/^$RE_VZTMPL_FILE_PATH$/,
+    backup => qr/^$RE_BACKUP_FILE_PATH$/,
 };

 my $RE_VOLNAME_FOR_VTYPE = {
     iso => qr/^$RE_ISO_FILE_PATH$/,
     vztmpl => qr/^$RE_VZTMPL_FILE_PATH$/,
+    backup => qr/^$RE_BACKUP_FILE_PATH$/,
 };

 my sub contains_parent_dir($path) {
diff --git a/src/PVE/Storage/Common/test/parser_tests.pl b/src/PVE/Storage/Common/test/parser_tests.pl
index 31575b66..96159608 100755
--- a/src/PVE/Storage/Common/test/parser_tests.pl
+++ b/src/PVE/Storage/Common/test/parser_tests.pl
@@ -193,14 +193,195 @@ my $volname_cases_vztmpl_invalid = [
     },
 ];

+my $volname_cases_backup_valid = [
+    {
+        path => 'vzdump-qemu-16110-2020_03_30-21_13_55.vma',
+        expected => {
+            type => 'qemu',
+            vmid => '16110',
+            file => 'vzdump-qemu-16110-2020_03_30-21_13_55.vma',
+            ext => 'vma',
+            'ext-archive' => 'vma',
+            'disk-path' => 'vzdump-qemu-16110-2020_03_30-21_13_55.vma',
+            path => 'vzdump-qemu-16110-2020_03_30-21_13_55.vma',
+            vtype => 'backup',
+            volname => 'backup/vzdump-qemu-16110-2020_03_30-21_13_55.vma',
+        },
+    },
+    {
+        path => 'vzdump-qemu-16110-2020_03_30-21_11_40.vma.gz',
+        expected => {
+            type => 'qemu',
+            vmid => '16110',
+            file => 'vzdump-qemu-16110-2020_03_30-21_11_40.vma.gz',
+            ext => 'vma.gz',
+            'ext-archive' => 'vma',
+            'ext-compression' => 'gz',
+            'disk-path' => 'vzdump-qemu-16110-2020_03_30-21_11_40.vma.gz',
+            path => 'vzdump-qemu-16110-2020_03_30-21_11_40.vma.gz',
+            vtype => 'backup',
+            volname => 'backup/vzdump-qemu-16110-2020_03_30-21_11_40.vma.gz',
+        },
+    },
+    {
+        path => 'vzdump-qemu-16110-2020_03_30-21_12_45.vma.lzo',
+        expected => {
+            type => 'qemu',
+            vmid => '16110',
+            file => 'vzdump-qemu-16110-2020_03_30-21_12_45.vma.lzo',
+            ext => 'vma.lzo',
+            'ext-archive' => 'vma',
+            'ext-compression' => 'lzo',
+            'disk-path' => 'vzdump-qemu-16110-2020_03_30-21_12_45.vma.lzo',
+            path => 'vzdump-qemu-16110-2020_03_30-21_12_45.vma.lzo',
+            vtype => 'backup',
+            volname => 'backup/vzdump-qemu-16110-2020_03_30-21_12_45.vma.lzo',
+        },
+    },
+    {
+        path => 'vzdump-qemu-16110-2020_03_30-21_13_55.vma.zst',
+        expected => {
+            type => 'qemu',
+            vmid => '16110',
+            file => 'vzdump-qemu-16110-2020_03_30-21_13_55.vma.zst',
+            ext => 'vma.zst',
+            'ext-archive' => 'vma',
+            'ext-compression' => 'zst',
+            'disk-path' => 'vzdump-qemu-16110-2020_03_30-21_13_55.vma.zst',
+            path => 'vzdump-qemu-16110-2020_03_30-21_13_55.vma.zst',
+            vtype => 'backup',
+            volname => 'backup/vzdump-qemu-16110-2020_03_30-21_13_55.vma.zst',
+        },
+    },
+    {
+        path => 'vzdump-lxc-16112-2020_03_30-21_39_30.tar.lzo',
+        expected => {
+            type => 'lxc',
+            vmid => '16112',
+            file => 'vzdump-lxc-16112-2020_03_30-21_39_30.tar.lzo',
+            ext => 'tar.lzo',
+            'ext-archive' => 'tar',
+            'ext-compression' => 'lzo',
+            'disk-path' => 'vzdump-lxc-16112-2020_03_30-21_39_30.tar.lzo',
+            path => 'vzdump-lxc-16112-2020_03_30-21_39_30.tar.lzo',
+            vtype => 'backup',
+            volname => 'backup/vzdump-lxc-16112-2020_03_30-21_39_30.tar.lzo',
+        },
+    },
+    {
+        path => 'vzdump-lxc-16112-2020_03_30-21_49_30.tar.gz',
+        expected => {
+            type => 'lxc',
+            vmid => '16112',
+            file => 'vzdump-lxc-16112-2020_03_30-21_49_30.tar.gz',
+            ext => 'tar.gz',
+            'ext-archive' => 'tar',
+            'ext-compression' => 'gz',
+            'disk-path' => 'vzdump-lxc-16112-2020_03_30-21_49_30.tar.gz',
+            path => 'vzdump-lxc-16112-2020_03_30-21_49_30.tar.gz',
+            vtype => 'backup',
+            volname => 'backup/vzdump-lxc-16112-2020_03_30-21_49_30.tar.gz',
+        },
+    },
+    {
+        path => 'vzdump-lxc-16112-2020_03_30-21_49_30.tar.zst',
+        expected => {
+            type => 'lxc',
+            vmid => '16112',
+            file => 'vzdump-lxc-16112-2020_03_30-21_49_30.tar.zst',
+            ext => 'tar.zst',
+            'ext-archive' => 'tar',
+            'ext-compression' => 'zst',
+            'disk-path' => 'vzdump-lxc-16112-2020_03_30-21_49_30.tar.zst',
+            path => 'vzdump-lxc-16112-2020_03_30-21_49_30.tar.zst',
+            vtype => 'backup',
+            volname => 'backup/vzdump-lxc-16112-2020_03_30-21_49_30.tar.zst',
+        },
+    },
+    {
+        path => 'vzdump-lxc-16112-2020_03_30-21_59_30.tgz',
+        expected => {
+            type => 'lxc',
+            vmid => '16112',
+            file => 'vzdump-lxc-16112-2020_03_30-21_59_30.tgz',
+            ext => 'tgz',
+            'ext-archive' => 'tgz',
+            'disk-path' => 'vzdump-lxc-16112-2020_03_30-21_59_30.tgz',
+            path => 'vzdump-lxc-16112-2020_03_30-21_59_30.tgz',
+            vtype => 'backup',
+            volname => 'backup/vzdump-lxc-16112-2020_03_30-21_59_30.tgz',
+        },
+    },
+    {
+        path => 'vzdump-openvz-16112-2020_03_30-21_39_30.tar.bz2',
+        expected => {
+            type => 'openvz',
+            vmid => '16112',
+            file => 'vzdump-openvz-16112-2020_03_30-21_39_30.tar.bz2',
+            ext => 'tar.bz2',
+            'ext-archive' => 'tar',
+            'ext-compression' => 'bz2',
+            'disk-path' => 'vzdump-openvz-16112-2020_03_30-21_39_30.tar.bz2',
+            path => 'vzdump-openvz-16112-2020_03_30-21_39_30.tar.bz2',
+            vtype => 'backup',
+            volname => 'backup/vzdump-openvz-16112-2020_03_30-21_39_30.tar.bz2',
+        },
+    },
+];
+
+my $volname_cases_backup_invalid = [
+    {
+        description => "Invalid file extension (1) (backup)",
+        args => {
+            path => 'vzdump-openvz-16112-2020_03_30-21_39_30.tar.zip',
+            vtype => 'backup',
+        },
+        expected => undef,
+    },
+    {
+        description => "Invalid file extension (2) (backup)",
+        args => {
+            path => 'vzdump-openvz-16112-2020_03_30-21_39_30.zip.gz',
+            vtype => 'backup',
+        },
+        expected => undef,
+    },
+    {
+        description => "Invalid file extension (3) (backup)",
+        args => {
+            path => 'vzdump-qemu-16110-2020_03_30-21_12_40.vma.xz',
+            vtype => 'backup',
+        },
+        expected => undef,
+    },
+    {
+        description => "Uppercase letter in file extension (1) (backup)",
+        args => {
+            path => 'vzdump-qemu-16110-2020_03_30-21_12_40.Tar.gz',
+            vtype => 'backup',
+        },
+        expected => undef,
+    },
+    {
+        description => "Uppercase letter in file extension (2) (backup)",
+        args => {
+            path => 'vzdump-qemu-16110-2020_03_30-21_12_40.tar.Gz',
+            vtype => 'backup',
+        },
+        expected => undef,
+    },
+];
+
 my $cases_valid_all = [
     $volname_cases_iso_valid,
     $volname_cases_vztmpl_valid,
+    $volname_cases_backup_valid,
 ];

 my $cases_invalid_all = [
     $volname_cases_iso_invalid,
     $volname_cases_vztmpl_invalid,
+    $volname_cases_backup_invalid,
 ];

 {
diff --git a/src/PVE/Storage/Plugin.pm b/src/PVE/Storage/Plugin.pm
index 6bfa5c11..4d63e0a5 100644
--- a/src/PVE/Storage/Plugin.pm
+++ b/src/PVE/Storage/Plugin.pm
@@ -28,6 +28,7 @@ use JSON;

 use base qw(PVE::SectionConfig);

+# TODO: Phase out these two constants
 use constant KNOWN_COMPRESSION_FORMATS => ('gz', 'lzo', 'zst', 'bz2');
 use constant COMPRESSOR_RE => join('|', KNOWN_COMPRESSION_FORMATS);

@@ -830,14 +831,10 @@ sub parse_volname {
         if ($vtype eq 'vztmpl') {
             return ($vtype, $volume_path, undef, undef, undef, undef, 'raw');
         }
-    }

-    if ($volname =~ m!^backup/([^/]+$PVE::Storage::BACKUP_EXT_RE_2)$!) {
-        my $fn = $1;
-        if ($fn =~ m/^vzdump-(openvz|lxc|qemu)-(\d+)-.+/) {
-            return ('backup', $fn, $2, undef, undef, undef, 'raw');
+        if ($vtype eq 'backup') {
+            return ($vtype, $volume_path, $parts->{vmid}, undef, undef, undef, 'raw');
         }
-        return ('backup', $fn, undef, undef, undef, undef, 'raw');
     }

     if ($volname =~ m!^snippets/([^/]+)$!) {
@@ -1721,37 +1718,41 @@ my sub get_subdir_files {
         }

         if ($vtype eq 'backup') {
-            return if $filename !~ m!/([^/]+$PVE::Storage::BACKUP_EXT_RE_2)$!;
+            my $parts = parse_path_as_volid_parts($storeid, $scfg, $path, $vtype);
+            return if !defined($parts);

-            my $original = $path;
-            my $format = $2;
-            $filename = $1;
+            my $format = $parts->{ext};
+            my $volume_path = $parts->{path};

-            # only match for VMID now, to avoid false positives (VMID in parent directory name)
-            return if defined($vmid) && $filename !~ m/\S+-$vmid-\S+/;
+            # Check if parsed VMID matched provided VMID in order to avoid
+            # false positives (VMID in parent directory name)
+            my $parsed_vmid = $parts->{vmid};
+            if (defined($vmid) && defined($parsed_vmid)) {
+                return if $vmid ne $parsed_vmid;
+            }

             my $info = {
-                volid => "$storeid:backup/$filename",
+                volid => $parts->{volid},
                 format => $format,
             };

-            my $archive_info = eval { PVE::Storage::archive_info($filename) } // {};
+            my $archive_info = eval { PVE::Storage::archive_info($volume_path) } // {};

             $info->{ctime} = $archive_info->{ctime} if defined($archive_info->{ctime});
             $info->{subtype} = $archive_info->{type} // 'unknown';

-            if (defined($vmid) || $filename =~ m!\-([1-9][0-9]{2,8})\-[^/]+\.${format}$!) {
-                $info->{vmid} = $vmid // $1;
+            if (defined($vmid) || defined($parsed_vmid)) {
+                $info->{vmid} = $vmid // $parsed_vmid;
             }

-            my $notes_filename = $original . NOTES_EXT;
+            my $notes_filename = $path . NOTES_EXT;
             if (-f $notes_filename) {
                 my $notes = PVE::Tools::file_read_firstline($notes_filename);
                 $info->{notes} = eval { decode('UTF-8', $notes, 1) } // $notes
                     if defined($notes);
             }

-            $info->{protected} = 1 if -e PVE::Storage::protection_file_path($original);
+            $info->{protected} = 1 if -e PVE::Storage::protection_file_path($path);

             return $info;
         }
--
2.47.3





  parent reply	other threads:[~2026-04-22 11:18 UTC|newest]

Thread overview: 55+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2026-04-22 11:12 [PATCH pve-storage, pve-manager v1 00/54] Fix #2884: Implement Subdirectory Scanning for Dir-Based Storage Types Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 01/54] test: plugin tests: run tests with at most 4 jobs Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 02/54] plugin, common: remove superfluous use of =pod command paragraph Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 03/54] common: add POD headings for groups of helpers Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 04/54] common: use Exporter module for PVE::Storage::Common Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 05/54] plugin: make get_subdir_files a proper subroutine and update style Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 06/54] plugin api: replace helpers w/ standalone subs, bump API version & age Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 07/54] common: prevent autovivification in plugin_get_vtype_subdir helper Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 08/54] plugin: break up needless if-elsif chain into separate if-blocks Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 09/54] plugin: adapt get_subdir_files helper of list_volumes API method Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 10/54] plugin: update code style of list_volumes plugin " Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 11/54] plugin: use closure for obtaining raw volume data in list_volumes Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 12/54] plugin: use closure for inner loop logic " Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 13/54] storage: update code style in function path_to_volume_id Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 14/54] storage: break up needless if-elsif chain in path_to_volume_id Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 15/54] storage: heave vtype file path parsing logic inside loop into helper Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 16/54] storage: clean up code that was moved into helper in path_to_volume_id Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 17/54] api: status: move content type assert for up-/downloads into helper Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 18/54] api: status: use helper from common module to get content directory Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 19/54] api: status: move up-/download file path parsing code into helper Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 20/54] api: status: simplify file content assertion logic for up-/download Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 21/54] test: guest import: add tests for PVE::GuestImport Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 22/54] tree-wide: introduce parsing module and replace usages of ISO_EXT_RE_0 Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 23/54] common: test: set up parser testing code, add tests for 'iso' vtype Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 24/54] tree-wide: replace usages of VZTMPL_EXT_RE_1 with parsing functions Max R. Carrara
2026-04-22 11:12 ` Max R. Carrara [this message]
2026-04-22 11:12 ` [PATCH pve-storage v1 26/54] tree-wide: replace usages of inline regexes for snippets with parsers Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 27/54] tree-wide: partially replace usages of regexes for 'import' vtype Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 28/54] tree-wide: replace remaining " Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 29/54] plugin: simplify recently refactored logic in parse_volname method Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 30/54] plugin: simplify recently refactored logic in get_subdir_files helper Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 31/54] storage: simplify recently refactored logic in path_to_volume_id sub Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 32/54] api: status: simplify recently added parsing helper for file transfers Max R. Carrara
2026-04-22 11:12 ` [PATCH pve-storage v1 33/54] plugin: use parsing helper in parse_volume_id sub Max R. Carrara
2026-04-22 11:13 ` [PATCH pve-storage v1 34/54] test: list volumes: reorganize and modernize test running code Max R. Carrara
2026-04-22 11:13 ` [PATCH pve-storage v1 35/54] test: list volumes: fix broken test checking for vmlist modifications Max R. Carrara
2026-04-22 11:13 ` [PATCH pve-storage v1 36/54] test: list volumes: introduce new format for test cases Max R. Carrara
2026-04-22 11:13 ` [PATCH pve-storage v1 37/54] test: list volumes: remove legacy code and migrate cases to new format Max R. Carrara
2026-04-22 11:13 ` [PATCH pve-storage v1 38/54] test: list volumes: document behavior wrt. undeclared content types Max R. Carrara
2026-04-22 11:13 ` [PATCH pve-storage v1 39/54] plugin: correct comment in get_subdir_files helper Max R. Carrara
2026-04-22 11:13 ` [PATCH pve-storage v1 40/54] test: parse volname: modernize code Max R. Carrara
2026-04-22 11:13 ` [PATCH pve-storage v1 41/54] test: parse volname: adapt tests regarding 'import' volume type Max R. Carrara
2026-04-22 11:13 ` [PATCH pve-storage v1 42/54] test: parse volname: move VM disk test creation into separate block Max R. Carrara
2026-04-22 11:13 ` [PATCH pve-storage v1 43/54] test: parse volname: move backup file test creation into sep. block Max R. Carrara
2026-04-22 11:13 ` [PATCH pve-storage v1 44/54] test: parse volname: parameterize test case creation for some vtypes Max R. Carrara
2026-04-22 11:13 ` [PATCH pve-storage v1 45/54] test: volume id: modernize code Max R. Carrara
2026-04-22 11:13 ` [PATCH pve-storage v1 46/54] test: volume id: rename 'volname' test case parameter to 'file' Max R. Carrara
2026-04-22 11:13 ` [PATCH pve-storage v1 47/54] test: filesystem path: modernize code Max R. Carrara
2026-04-22 11:13 ` [PATCH pve-storage v1 48/54] fix #2884: implement nested subdir scanning and support 'iso' vtype Max R. Carrara
2026-04-22 11:13 ` [PATCH pve-storage v1 49/54] fix #2884: support nested subdir scanning for 'vztmpl' volume type Max R. Carrara
2026-04-22 11:13 ` [PATCH pve-storage v1 50/54] fix #2884: support nested subdir scanning for 'snippets' vtype Max R. Carrara
2026-04-22 11:13 ` [PATCH pve-storage v1 51/54] test: add more tests for 'import' vtype & guard against nested subdirs Max R. Carrara
2026-04-22 11:13 ` [PATCH pve-storage v1 52/54] test: add tests guarding against subdir scanning for vtypes Max R. Carrara
2026-04-22 11:13 ` [PATCH pve-storage v1 53/54] storage api: mark old public regexes for removal, bump APIVER & APIAGE Max R. Carrara
2026-04-22 11:13 ` [PATCH pve-manager v1 54/54] fix #2884: ui: storage: add field for 'max-scan-depth' property Max R. Carrara

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20260422111322.257380-26-m.carrara@proxmox.com \
    --to=m.carrara@proxmox.com \
    --cc=pve-devel@lists.proxmox.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
Service provided by Proxmox Server Solutions GmbH | Privacy | Legal